@@ -6,17 +6,16 @@ C     outputs: coefc, coefz, thetaout
      +     start_count, start_zero, mustart_count, mustart_zero, 
      +     offsetx, offsetz, nlambda, lambda_count,
      +     lambda_zero, alpha_count, alpha_zero,  
-     +     gam_count, gam_zero, standardize, penaltyfactor_count, 
+     +     gam_count, gam_zero, penaltyfactor_count, 
      +     penaltyfactor_zero, maxit, eps, family,
      +     penalty, trace, coefc, coefz, yhat, iter,
      +     del, rescale, thresh, epsbino, 
      +     theta_fixed, maxit_theta, theta, thetaout)
       implicit none
       integer n,i,ii,j,kx, kz, penalty,nlambda,family, 
-     +     standardize, maxit, y1(n), trace, iter, 
+     +     maxit, y1(n), trace, iter, 
      +     rescale, jk_count, jk_zero, stopit,m_count_act, maxit_theta,
-     +     m_zero_act, AllocateStatus, satu, 
-     +     varsel_count(kx), varsel_count_old(kx),
+     +     m_zero_act, satu, varsel_count(kx), varsel_count_old(kx),
      +     varsel_zero(kz), varsel_zero_old(kz), theta_fixed
       double precision x(n, kx), z(n, kz), weights(n), 
      +     start_count(kx+1), dpois, dnbinom, start_zero(kz+1), 
@@ -82,7 +81,7 @@ C     outputs: coefc, coefz, thetaout
      +           m_count_act, m_zero_act, start_count_act, 
      +           start_zero_act, mustart_count, mustart_zero, offsetx, 
      +           offsetz, lambda_count(i), lambda_zero(i), alpha_count,
-     +           alpha_zero, gam_count, gam_zero, standardize,
+     +           alpha_zero, gam_count, gam_zero, 
      +           penaltyfactor_count_act, penaltyfactor_zero_act,
      +           maxit, eps, family, penalty, trace, yhat, iter, del,
      +           rescale, thresh, epsbino, theta_fixed,
